/*

					W3C Sample Code Library libwww PLAIN TEXT STREAM




!Plain text object!

*/

/*
**	(c) COPYRIGHT MIT 1995.
**	Please first read the full copyright statement in the file COPYRIGH.
*/

/*

This module is implemented by HTPlain.c, and
it is a part of the  W3C
Sample Code Library.

*/

#ifndef HTPLAIN_H
#define HTPLAIN_H

#include "HTFormat.h"

extern HTConverter HTPlainPresent;

#endif

/*



@(#) $Id: HTPlain.html,v 2.20 1998/05/14 02:10:55 frystyk Exp $


*/
